@@ -12,6 +12,7 @@ entries in the form ``(config_key, match, SecurityRisk)``.
 """
 
 from .cmdline   import _BUILTIN_DEFS as _CMDLINE_DEFS
+from .env       import _BUILTIN_DEFS as _ENV_DEFS
 from .fit       import _BUILTIN_DEFS as _FIT_DEFS
 from .fs        import _BUILTIN_DEFS as _FS_DEFS
 from .lib       import _BUILTIN_DEFS as _LIB_DEFS
@@ -20,6 +21,7 @@ from .net       import _BUILTIN_DEFS as _NET_DEFS
 # Aggregate builtins into a main set of definitions
 _BUILTIN_DEFS = (
     _CMDLINE_DEFS +
+    _ENV_DEFS +
     _FIT_DEFS +
     _FS_DEFS +
     _LIB_DEFS +
