@@ -14,6 +14,10 @@ def _enabled_with_legacy_image(value: str, config: dict):
     return value and config.get('CONFIG_LEGACY_IMAGE_FORMAT', False)
 
 
+def _enabled_without_full_check(value: str, config: dict):
+    return value and not config.get('CONFIG_FIT_FULL_CHECK', False)
+
+
 _BUILTIN_DEFS = (
     ('CONFIG_FIT_SIGNATURE', True, {
         'identifier': 'CVE-2018-3968',
@@ -64,7 +68,7 @@ _BUILTIN_DEFS = (
         #
         'recommendation': 'Update to U-Boot 2018.09.\n',
 
-        'affected_versions': ('0.0', '2018.09')
+        'affected_versions': ('2013.07-rc1', '2018.09')
     }),
 
     # Vestigial reference design configuration that results in behavior similar to CVE-2018-3968
@@ -118,7 +122,7 @@ _BUILTIN_DEFS = (
                 <https://labs.f-secure.com/advisories/das-u-boot-verified-boot-bypass>
         """),
 
-        'recommendation': dedent("""\'
+        'recommendation': dedent("""\
             Update to U-Boot 2020.04, or otherwise backport fixes merged in commit e0718b3a.
 
             Per the F-Secure advisory, one possible mitigation is to explicitly specify the
@@ -134,10 +138,57 @@ _BUILTIN_DEFS = (
 
         """),
 
-        # FIXME: Advisory is a bit iffy on the 2018.03 minimum version, so we just use 0's here.
-        # Need to revisit this when I have time to spend on git archaeology in order to determine
-        # the first relevant version. Presumably there exists a version where the affected FIT
-        # signature or configuration functionally isn't even present, and this will be our minimum.
-        'affected_versions': ('0.0', '2020.04-rc5'),
+        'affected_versions': ('2013.07-rc1', '2020.04-rc5'),
+    }),
+
+    ('CONFIG_FIT_SIGNATURE', True, {
+        'identifier': 'CVE-2021-27138',
+        'impact': SecurityImpact.VERIFICATION_BYPASS,
+        'summary': 'FIT signature bypass via unit addresses',
+
+        'description': dedent("""\
+                As of 2017, U-Boot no longer uses unit addresses in FIT images. However, because
+                libfdt can match nodes ignoring any unit addressees, it is possible that signature
+                verification checks the wrong node if one with the same name but different unit
+                address is inserted.
+        """),
+
+        'recommendation': 'Update to U-Boot 2021.04.',
+
+        # FIT images introduced in 782cfbb2
+        'affected_versions': ('2013.07-rc1', '2021.04')
+    }),
+
+    ('CONFIG_FIT_SIGNATURE', True, {
+        'identifier': 'CVE-2021-27097',
+        'impact': SecurityImpact.VERIFICATION_BYPASS,
+        'summary': 'FIT signature bypass via multiple root nodes',
+
+        'description': dedent("""
+            A malformed FIT image, such as one containing multiple root nodes, could cause the
+            wrong parent node to be processed during validation.
+        """),
+
+        'recommendation': 'Update to U-Boot 2021.04 and ensure CONFIG_FIT_FULL_CHECK=y.',
+
+        # FIT images introduced in 782cfbb2
+        'affected_versions': ('2013.07-rc1', '2021.04')
+    }),
+
+    ('CONFIG_FIT_SIGNATURE', _enabled_without_full_check, {
+        'identifier': 'CONFIG_FIT_FULL_CHECK',
+        'impact': SecurityImpact.VERIFICATION_BYPASS,
+        'summary': 'Full FIT validation checks are not enabled',
+        'description': dedent("""\
+            CONFIG_FIT_SIGNATURE=y is intended to imply CONFIG_FIT_FULL_CHECK=y, but
+            CONFIG_FIT_FULL_CHECK does not appear to be enabled in the analyzed config file. The
+            "full check" is necessary to avoid security risks (e.g. verification bypasses)
+            resulting from malformed FIT constructs that can otherwise be rejected.
+        """),
+
+        'recommendation': 'Ensure CONFIG_FIT_FULL_CHECK=y.',
+
+        # This needs to be enabled in 2021.04-rc2 onward
+        'affected_versions': ('2021.04-rc2', '9999.99')
     })
 )
